Crew class

Constructors

Crew({required String name, required String agency, required String image, required String wikipedia, required List<String> launches, required String status, required String id})
Crew.fromJson(Map<String, dynamic> json)

Properties

agency ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
image ↔ String
getter/setter pair
launches ↔ List<String>
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
getter/setter pair
wikipedia ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited