HeatShield class

Constructors

HeatShield({required String material, required num sizeMeters, required num tempDegrees, required String devPartner})
HeatShield.fromJson(Map<String, dynamic> json)

Properties

devPartner ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
material ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeMeters ↔ num
getter/setter pair
tempDegrees ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited