Thrusters class

Constructors

Thrusters({required String type, required int amount, required int pods, required String fuel1, required String fuel2, required int isp, required Thrust thrust})
Thrusters.fromJson(Map<String, dynamic> json)

Properties

amount ↔ int
getter/setter pair
fuel1 ↔ String
getter/setter pair
fuel2 ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isp ↔ int
getter/setter pair
pods ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thrust ↔ Thrust
getter/setter pair
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited