Cores class

Constructors

Cores({required String core, required num flight, required bool gridfins, required bool legs, required bool reused, required bool landingAttempt, required bool landingSuccess, required String landingType, required String landpad})
Cores.fromJson(Map<String, dynamic> json)

Properties

core ↔ String
getter/setter pair
flight ↔ num
getter/setter pair
gridfins ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
landingAttempt ↔ bool
getter/setter pair
landingSuccess ↔ bool
getter/setter pair
landingType ↔ String
getter/setter pair
landpad ↔ String
getter/setter pair
legs ↔ bool
getter/setter pair
reused ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited